@@ -1,13 +1,14 @@
 """Typed methods from pythonapi."""
 from __future__ import annotations
 
-import _ctypes
 import ctypes
 from collections.abc import Callable
-from ctypes import pythonapi, py_object, pointer, POINTER
-from typing import Type, Union
+from ctypes import POINTER, py_object, pythonapi
+from typing import Union
 
-from einspect.compat import python_req, Version
+import _ctypes
+
+from einspect.compat import Version, python_req
 
 __all__ = ("Py", "Py_ssize_t", "PyObj_FromPtr")
 
@@ -17,7 +18,6 @@ Py_ssize_t = ctypes.c_ssize_t
 ObjectOrRef = Union[py_object, object]
 IntSize = Union[int, Py_ssize_t]
 PyObjectPtr = POINTER(py_object)
-ObjectPtr = Union[PyObjectPtr, Type[ctypes.byref]]
 
 
 class Py:
@@ -28,8 +28,8 @@ class Py:
     Increment the reference count of an object.
     https://docs.python.org/3/c-api/refcounting.html#c.Py_IncRef
     """
-    IncRef.argtypes = (py_object,)
-    IncRef.restype = None
+    IncRef.argtypes = (py_object,)  # type: ignore
+    IncRef.restype = None  # type: ignore
 
     DecRef: Callable[[ObjectOrRef], None] = pythonapi["Py_DecRef"]
     """
@@ -37,8 +37,8 @@ class Py:
     Increments ref-count and returns the object.
     https://docs.python.org/3/c-api/refcounting.html#c.Py_DecRef
     """
-    DecRef.argtypes = (py_object,)
-    DecRef.restype = None
+    DecRef.argtypes = (py_object,)  # type: ignore
+    DecRef.restype = None  # type: ignore
 
     NewRef: Callable[[ObjectOrRef], None] = python_req(Version.PY_3_10) or pythonapi["Py_NewRef"]
     """
@@ -46,8 +46,8 @@ class Py:
     Returns the object.
     https://docs.python.org/3/c-api/refcounting.html#c.Py_NewRef
     """
-    NewRef.argtypes = (py_object,)
-    NewRef.restype = py_object
+    NewRef.argtypes = (py_object,)  # type: ignore
+    NewRef.restype = py_object  # type: ignore
 
     class Tuple:
         Size: Callable[[ObjectOrRef], int] = pythonapi["PyTuple_Size"]
@@ -55,16 +55,16 @@ class Py:
         Return the size of a tuple object.
         https://docs.python.org/3/c-api/tuple.html#c.PyTuple_Size
         """
-        Size.argtypes = (py_object,)
-        Size.restype = Py_ssize_t
+        Size.argtypes = (py_object,)  # type: ignore
+        Size.restype = Py_ssize_t  # type: ignore
 
         GetItem: Callable[[ObjectOrRef, IntSize], object] = pythonapi["PyTuple_GetItem"]
         """
         Return the item at position index in the tuple o.
         https://docs.python.org/3/c-api/tuple.html#c.PyTuple_GetItem
         """
-        GetItem.argtypes = (py_object, Py_ssize_t)
-        GetItem.restype = py_object
+        GetItem.argtypes = (py_object, Py_ssize_t)  # type: ignore
+        GetItem.restype = py_object  # type: ignore
 
         SetItem: Callable[[ObjectOrRef, IntSize, ObjectOrRef], None] = pythonapi["PyTuple_SetItem"]
         """
@@ -75,10 +75,10 @@ class Py:
             - This function steals a reference to v.
             - Requires tuple o to have a reference count == 1.
         """
-        SetItem.argtypes = (py_object, Py_ssize_t, py_object)
-        SetItem.restype = None
+        SetItem.argtypes = (py_object, Py_ssize_t, py_object)  # type: ignore
+        SetItem.restype = None  # type: ignore
 
-        Resize: Callable[[ObjectPtr, IntSize], None] = pythonapi["_PyTuple_Resize"]
+        Resize: Callable[[PyObjectPtr, IntSize], None] = pythonapi["_PyTuple_Resize"]
         """
         Resize the tuple to the specified size.
         https://docs.python.org/3/c-api/tuple.html#c._PyTuple_Resize
@@ -87,8 +87,8 @@ class Py:
             - Not part of the documented limited C API.
             - Requires tuple o to have ref-count = 1 or size = 0
         """
-        Resize.argtypes = (POINTER(py_object), Py_ssize_t)
-        Resize.restype = None
+        Resize.argtypes = (POINTER(py_object), Py_ssize_t)  # type: ignore
+        Resize.restype = None  # type: ignore
 
     class Type:
         Modified: Callable[[ObjectOrRef], None] = pythonapi["PyType_Modified"]
@@ -98,9 +98,9 @@ class Py:
         - This function must be called after any manual modification of the attributes 
           or base classes of the type.
         """
-        Modified.argtypes = (py_object,)
-        Modified.restype = None
+        Modified.argtypes = (py_object,)  # type: ignore
+        Modified.restype = None  # type: ignore
 
 
-PyObj_FromPtr = _ctypes.PyObj_FromPtr
+PyObj_FromPtr: Callable[[IntSize], object] = _ctypes.PyObj_FromPtr
 """(Py_ssize_t ptr) -> Py_ssize_t"""
