@@ -4,7 +4,7 @@ from __future__ import annotations
 import sys
 from dataclasses import dataclass
 from enum import Enum
-from typing import Generic, TypeVar, NoReturn
+from typing import Generic, NoReturn, TypeVar
 
 
 class Version(Enum):
