@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import ctypes
 from ctypes import pythonapi
 from typing import Any
@@ -5,7 +7,11 @@ from typing import Any
 
 def address(obj: Any) -> int:
     """Return the address of an object."""
-    return ctypes.c_void_p.from_buffer(ctypes.py_object(obj)).value
+    source = ctypes.py_object(obj)
+    addr = ctypes.c_void_p.from_buffer(source).value
+    if addr is None:
+        raise ValueError("address: NULL object")
+    return addr
 
 
 def new_ref(obj: Any) -> int:
